@@ -5,7 +5,7 @@ package Data::Tubes;
 use strict;
 use warnings;
 use English qw< -no_match_vars >;
-$Data::Tubes::VERSION = '0.723';
+our $VERSION = '0.723005';
 use Exporter qw< import >;
 
 use Log::Log4perl::Tiny qw< :easy :dead_if_first LOGLEVEL >;
@@ -14,6 +14,7 @@ use Data::Tubes::Util qw<
   load_sub
   normalize_args
   resolve_module
+  tube
 >;
 
 our @EXPORT_OK = (
@@ -101,10 +102,5 @@ sub summon {    # sort-of import
    } ## end for my $r (@_)
 } ## end sub summon
 
-sub tube {
-   my $locator = shift;
-   return load_sub($locator)->(@_);
-} ## end sub tube
-
 1;
 __END__
